export declare type CloneableRequest = {
    body: ArrayBuffer | null;
    cache: RequestCache;
    credentials: RequestCredentials;
    destination: RequestDestination;
    headers: [string, string][];
    integrity: string;
    keepalive: boolean;
    method: string;
    mode: RequestMode;
    redirect: RequestRedirect;
    referrer: string;
    referrerPolicy: ReferrerPolicy;
    url: string;
};
export declare type CloneableResponse = {
    body: ArrayBuffer | null;
    headers: [string, string][];
    ok: boolean;
    redirected: boolean;
    status: number;
    statusText: string;
    type: ResponseType;
    url: string;
};
export declare type CloneableError = {
    name: string;
    message: string;
    cause?: CloneableRequest | CloneableResponse;
    stack?: string;
};
/**
 * Construct a cloneable object for a given Request or Response.
 * @see [The structured clone algorithm - Web APIs | MDN]{@link https://developer.mozilla.org/en-US/docs/Web/API/Web_Workers_API/Structured_clone_algorithm}
 */
declare function toCloneable(request: Request): Promise<CloneableRequest>;
declare function toCloneable(response: Response): Promise<CloneableResponse>;
declare function toCloneable(error: Error): Promise<CloneableError>;
declare function toCloneable(r: Request | Response): Promise<CloneableRequest | CloneableResponse>;
declare function toCloneable(r: Response | Error): Promise<CloneableResponse | CloneableError>;
export default toCloneable;
//# sourceMappingURL=toCloneable.d.ts.map