async function toCloneable(r) {
    if (r instanceof Error) {
        const { name, message, cause, stack, } = r;
        const cloneable = { name, message };
        if (cause)
            cloneable.cause = await toCloneable(cause);
        if (stack)
            cloneable.stack = stack;
        return cloneable;
    }
    const arrayBuffer = await r.clone().arrayBuffer();
    const body = arrayBuffer.byteLength > 0 ? arrayBuffer : null;
    const headers = [...r.headers];
    // To cloneable request.
    if (r instanceof Request) {
        const { cache, credentials, destination, integrity, keepalive, method, mode, redirect, referrer, referrerPolicy, url, } = r;
        return {
            body,
            cache,
            credentials,
            destination,
            headers,
            integrity,
            keepalive,
            method,
            mode,
            redirect,
            referrer,
            referrerPolicy,
            url,
        };
    }
    // To cloneable response.
    const { ok, redirected, status, statusText, type, url, } = r;
    return {
        body,
        headers,
        ok,
        redirected,
        status,
        statusText,
        type,
        url,
    };
}
export default toCloneable;
